Module blaxel.core.client.models.expiration_policy
==================================================

Classes
-------

`ExpirationPolicy(action: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, type_: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, value: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Expiration policy for sandbox lifecycle management
    
    Attributes:
        action (Union[Unset, str]): Action to take when policy is triggered
        type_ (Union[Unset, str]): Type of expiration policy
        value (Union[Unset, str]): Duration value (e.g., '1h', '24h', '7d')
    
    Method generated by attrs for class ExpirationPolicy.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `action: blaxel.core.client.types.Unset | str`
    :

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `type_: blaxel.core.client.types.Unset | str`
    :

    `value: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :